@@ -1,4 +1,4 @@
-"""xbrl_parser - This parser can parse XBRL documents"""
+"""xbrl_parser - Parser for parsing XBRL and iXBRL files (instance documents, taxonomy schemas, taxonomy linkbases)."""
 
 """
 This package contains all classes and methods for parsing both XBRL and iXBRL
@@ -61,7 +61,7 @@ class ContextParseException(InstanceParseException):
     pass
 
 
-__version__ = '1.0.0'
+__version__ = '1.1.0'
 __author__ = 'Manuel Schmidt <hello@schmidt-manuel.de>'
 __all__ = [
     XbrlParseException,
